@@ -39,7 +39,6 @@
 #define NC_FILE_EOF    5
 #define NC_REOPEN_REQUIRED 6
 #define NC_FILE_DELETED 7
-#define NC_LAST_MSG_SENT 8
 
 /* indicates that the LogPipe was initialized */
 #define PIF_INITIALIZED       0x0001
@@ -261,6 +260,8 @@ LogPipe *log_pipe_new(GlobalConfig *cfg);
 void log_pipe_init_instance(LogPipe *self, GlobalConfig *cfg);
 void log_pipe_forward_notify(LogPipe *self, gint notify_code, gpointer user_data);
 EVTTAG *log_pipe_location_tag(LogPipe *pipe);
+void log_pipe_attach_expr_node(LogPipe *self, LogExprNode *expr_node);
+void log_pipe_detach_expr_node(LogPipe *self);
 
 static inline GlobalConfig *
 log_pipe_get_config(LogPipe *s)
@@ -351,11 +352,8 @@ log_pipe_queue(LogPipe *s, LogMessage *msg, const LogPathOptions *path_options)
 
       local_path_options.flow_control_requested = 1;
       path_options = &local_path_options;
-      if (G_UNLIKELY(debug_flag))
-        {
-          msg_debug("Requesting flow control",
-                    log_pipe_location_tag(s));
-        }
+
+      msg_trace("Requesting flow control", log_pipe_location_tag(s));
     }
 
   if (s->queue)
